<?php
/**
 * Email library
 *
 * @package wp-video-capture
 */

if ( ! class_exists( 'WP_Video_Capture_Email' ) ) {

	/**
	 * WP_Video_Capture_Email class
	 */
	class WP_Video_Capture_Email {

		/**
		 * Constructor.
		 *
		 * @param string $hostname WP installation host name.
		 */
		public function __construct( $hostname ) {

			$this->hostname = $hostname;

			// Email headers.
			$this->headers   = [];
			$this->headers[] = 'MIME-Version: 1.0';
			$this->headers[] = 'Content-type: text/html; charset=utf-8';
			$this->headers[] = 'From: Video Recorder Plugin <vidrack@' . preg_replace( '/^www\./', '', $hostname ) . '>';
			$this->headers[] = 'Reply-to: Vidrack <info@vidrack.com>';

		}

		/**
		 * Notifies user about newly uploaded video.
		 *
		 * @param string $to user email.
		 * @param string $filename video name.
		 */
		public function send_new_video_email( $to, $filename ) {
			wp_mail(
				$to,
				__( 'New video recorded at', 'video-capture' ) . ' ' . $this->hostname . ' website',
				'
			<p>' . __( 'Hello', 'video-capture' ) . ',<br/>
			<br/>
			' . __( 'You have a new video at', 'video-capture' ) . ' ' . $this->hostname . '!<br/>
			<a href="https://vidrack-media.s3.amazonaws.com/' . $filename . '" download>' . __( 'Click here to download', 'video-capture' ) . '</a><br/>
			<br/>
			<p>' . __( 'Have trouble playing videos? Download', 'video-capture' ) . ' <a href="https://www.videolan.org/" target="_blank">VLC media player</a>!</p>
			<br/>
			' . __( 'Kind regards', 'video-capture' ) . ',<br/>
			' . __( 'Vidrack Team', 'video-capture' ) . '<br/>
			<br/>
			<a href="https://vidrack.com" target="_blank">vidrack.com</a>
			',
				$this->headers
			);
		}
	}

}
